@@ -144,6 +144,23 @@ R <- sqrt((cor.cos^2 + cor.sin^2 - 2 * cor.cos * cor.sin * cor.cs)/(1-cor.cs^2))
 return(R) }
 
 
+"circadian.plot" <-
+function(angle,x=NULL,hours=TRUE,title="Polar plot") {
+if(hours) { angle <- angle*2*pi/24 }
+x1 <- cos(angle) * x
+y1 <- sin(angle) * x
+maxx <- max(x)
+plot(x1,y1,axes=FALSE,xlab="",ylab="",xlim=c(-maxx,maxx),ylim=c(-maxx,maxx),asp=1) 
+segments  <- 51
+ angles <- (0:segments) * 2 * pi/segments
+unit.circle <- cbind(cos(angles), sin(angles))
+points(unit.circle*maxx,typ="l")
+text(maxx,0,"24",pos=4)
+text(-maxx,0,"12",pos=2)
+text(0,maxx,"6",pos=3)
+text(0,-maxx,"18",pos=1)
+}
+
 #deprecated
 "circadian.linear.cor.2" <- 
 function(angle,x,hours=TRUE) {
