@@ -50,8 +50,9 @@ if (mat) { ncol <- length(answer[[1]])  #the more complicated case. How to reord
         
 	  	rn[k] <- paste(row.names[var],group,sep="")
 	    #mat.ans[k,1] <- group
-	    for (stat in 1:n.col) {
-	   	 mat.ans[k,stat] <- answer[[group]][[stat]][var] } 
+	    for (stat in 1:n.col) {if(!is.null(answer[[group]][[stat]][var])) {
+	   	 mat.ans[k,stat] <- answer[[group]][[stat]][var]} else { mat.ans[k,stat] <- NA }
+	   	  } 
 	     k <- k + 1}
 	   }
 	   answer <- data.frame( labels.ans,mat.ans) 
