@@ -5,7 +5,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
   
    if (n!=dim(r)[1]) {
       				n.obs <- dim(r)[1] 
-      				if(scores) {x.matrix <- r
+      				if(scores) {x.matrix <- as.matrix(r)  #matrices are required for the substitution to work
     
                   if(missing) {
         			miss <- which(is.na(x.matrix),arr.ind=TRUE)
@@ -139,4 +139,5 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
   #correct August 25, 2009 to return result$values
   #modified August 25 to return result$stats
   #modified November 20, 2011 to allow multiple scoring approaches to give component scores
-  #modified December 21, 2011 to allow for finding the pc of covariances 
\ No newline at end of file
+  #modified December 21, 2011 to allow for finding the pc of covariances 
+  #modified June 19, 2012 to fix a missing value problem reported by Neil Stewart
\ No newline at end of file
