@@ -252,7 +252,10 @@ function(x,y) {
 
 
 "cor.smooth" <- function(x) {
-eigens <- eigen(x)
+eigens <- try(eigen(x),TRUE)
+if(class(eigens)== as.character("try-error")) {warning('I am sorry, there is something seriously wrong with the correlation matrix,\ncor.smooth failed to  smooth it because some of the eigen values are NA.  \nAre you sure you specified the data correctly?')
+                                                     } else {
+                                                        
 if(min(eigens$values) < .Machine$double.eps)  {warning("Matrix was not positive definite, smoothing was done")
 eigens$values[eigens$values  < .Machine$double.eps] <- 100 * .Machine$double.eps
 nvar <- dim(x)[1]
@@ -264,4 +267,6 @@ x <- eigens$vectors %*% diag(eigens$values) %*% t(eigens$vectors)
 x <- cov2cor(x)
 colnames(x) <- cnames
 rownames(x) <- rnames}
+}
 return(x)}
+#modified January 9, 2012 to add the try so we don't fail (just complain) if the data are bad.
